#ifndef NT2_INCLUDE_CONSTANTS__90_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS__90_HPP_INCLUDED

#include <nt2/trigonometric/include/constants/_90.hpp>

#endif
